/* This testcase is part of GDB, the GNU debugger.

   Copyright 2019-2026 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* First dummy function.  */

int
first (char *x)
{
  asm ("first_label: .globl first_label");
  return 0;
}

/* Second dummy function.  */

int
second (char *x)
{
  asm ("second_label: .globl second_label");
  return 0;
}


int
main (void)
{
  asm ("main_label: .globl main_label");

  first (0);
  second (0);
  return 0;
}
